@@ -731,13 +731,13 @@ RAB <- function(x, percent = FALSE, unname = FALSE){
 #'
 #' @examples
 #'
-#' Generate <- function(condition, fixed_objects = NULL) {
+#' Generate <- function(condition, fixed_objects) {
 #'    X <- rep(0:1, each = 50)
 #'    y <- 10 + 5 * X + rnorm(100, 0, .2)
 #'    data.frame(y, X)
 #' }
 #'
-#' Analyse <- function(condition, dat, fixed_objects = NULL) {
+#' Analyse <- function(condition, dat, fixed_objects) {
 #'    mod <- lm(y ~ X, dat)
 #'    so <- summary(mod)
 #'    ret <- c(SE = so$coefficients[,"Std. Error"],
@@ -745,7 +745,7 @@ RAB <- function(x, percent = FALSE, unname = FALSE){
 #'    ret
 #' }
 #'
-#' Summarise <- function(condition, results, fixed_objects = NULL) {
+#' Summarise <- function(condition, results, fixed_objects) {
 #'    MSRSE(SE = results[,1:2], SD = results[,3:4])
 #' }
 #'
@@ -1028,10 +1028,8 @@ ECR <- function(CIs, parameter, tails = FALSE, CI_width = FALSE,
     if(is.data.frame(parameter)) parameter <- unlist(parameter)
     stopifnot(is.vector(parameter))
     if(length(parameter) != 1L) stopifnot(length(parameter) == nrow(CIs))
-    if(CIs[1,1] > CIs[1,2]){
-        warning('First column not less than second. Temporarily switching')
-        CIs <- cbind(CIs[,2L], CIs[,1L])
-    }
+    if(any(CIs[,1] > CIs[,2]))
+        stop('lower CIs higher than upper CIs. Please inspect')
     if(CI_width){
         ret <- mean(CIs[,2L] - CIs[,1L])
         if(!is.null(names))
